cryptominisat: A SAT solver
===========================

Description
-----------

   CryptoMiniSat is a SAT solver that aims to become a premiere SAT
   solver with all the features and speed of successful SAT solvers,
   such as MiniSat and PrecoSat. The long-term goals of CryptoMiniSat
   are to be an efficient sequential, parallel and distributed
   solver. There are solvers that are good at one or the other,
   e.g. ManySat (parallel) or PSolver (distributed), but we wish to
   excel at all.

   CryptoMiniSat 2.5 won the SAT Race 2010 among 20 solvers submitted
   by researchers and industry.

License
-------

MIT License


Upstream Contact
----------------

-  Authors: Mate Soos
-  Email: soos.mate@gmail.com
-  Website: http://www.msoos.org/
-  Releases: https://github.com/msoos/cryptominisat/releases


Special Update/Build Instructions
---------------------------------

CryptoMiniSat's tarball downloaded from github is called VERSION.tar.gz
and should be renamed to cryptominisat-VERSION.tar.gz
